@@ -6,15 +6,17 @@ from graphgallery.utils.conversion import (check_and_convert, sparse_adj_to_edge
                                            astensor)
 
 from graphgallery.utils.data_utils import normalize_adj, normalize_x, Bunch, sample_mask
+from graphgallery.config import set_epsilon, set_floatx, set_intx, floatx, intx
+from graphgallery.utils.tensor_utils import normalize_adj_tensor, normalize_edge_tensor
 from graphgallery.utils.shape_utils import repeat
+from graphgallery.utils.type_check import *
 from graphgallery.utils.tqdm import tqdm
 
-
 from graphgallery import nn
 from graphgallery import utils
 from graphgallery import sequence
 
 
-__version__ = '0.1.5'
+__version__ = '0.1.6'
 
 __all__ = ['graphgallery', 'nn', 'utils', 'sequence', '__version__']
