@@ -1,6 +1,8 @@
 from graphgallery.utils.history import History
 from graphgallery.utils.data_utils import Bunch, sample_mask, normalize_adj, normalize_x
-from graphgallery.utils.shape_utils import repeat
+from graphgallery.utils.shape_utils import repeat, set_equal_in_length, get_length
 from graphgallery.utils.tensor_utils import normalize_edge_tensor
 from graphgallery.utils.gdc import GDC
 from graphgallery.utils.probar import progress_bar
+from graphgallery.utils.degree import degree_mixing_matrix, degree_assortativity_coefficient
+from graphgallery.utils.tqdm import tqdm
